@@ -81,26 +81,19 @@ static void          interface_base_finalize( NactIActionTabInterface *klass );
 
 static void          on_iactions_list_column_edited( NactIActionTab *instance, NAObject *object, gchar *text, gint column );
 static void          on_tab_updatable_selection_changed( NactIActionTab *instance, gint count_selected );
-static void          on_tab_updatable_provider_changed( NactIActionTab *instance, NAObjectItem *item );
 
 static void          on_target_selection_toggled( GtkToggleButton *button, NactIActionTab *instance );
 static void          on_target_location_toggled( GtkToggleButton *button, NactIActionTab *instance );
-
 static void          check_for_label( NactIActionTab *instance, GtkEntry *entry, const gchar *label );
 static void          on_label_changed( GtkEntry *entry, NactIActionTab *instance );
 static void          set_label_label( NactIActionTab *instance, const gchar *color );
-
 static void          on_target_toolbar_toggled( GtkToggleButton *button, NactIActionTab *instance );
-
 static void          on_toolbar_same_label_toggled( GtkToggleButton *button, NactIActionTab *instance );
 static void          toolbar_same_label_set_sensitive( NactIActionTab *instance, NAObjectItem *item );
-
 static void          setup_toolbar_label( NactIActionTab *instance, NAObjectItem *item, const gchar *label );
 static void          on_toolbar_label_changed( GtkEntry *entry, NactIActionTab *instance );
 static void          toolbar_label_set_sensitive( NactIActionTab *instance, NAObjectItem *item );
-
 static void          on_tooltip_changed( GtkEntry *entry, NactIActionTab *instance );
-
 static GtkTreeModel *create_stock_icon_model( void );
 static void          icon_combo_list_fill( GtkComboBoxEntry* combo );
 static void          on_icon_browse( GtkButton *button, NactIActionTab *instance );
@@ -109,13 +102,6 @@ static gint          sort_stock_ids( gconstpointer a, gconstpointer b );
 static gchar        *strip_underscore( const gchar *text );
 static void          release_icon_combobox( NactIActionTab *instance );
 
-static GtkButton    *get_enabled_button( NactIActionTab *instance );
-static void          on_enabled_toggled( GtkToggleButton *button, NactIActionTab *instance );
-
-static void          on_readonly_toggled( GtkToggleButton *button, NactIActionTab *instance );
-
-static void          display_provider_name( NactIActionTab *instance, NAObjectItem *item );
-
 GType
 nact_iaction_tab_get_type( void )
 {
@@ -206,11 +192,12 @@ nact_iaction_tab_initial_load_toplevel( NactIActionTab *instance )
 	GtkFrame *frame;
 	gint size;
 
-	g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
 	g_return_if_fail( NACT_IS_IACTION_TAB( instance ));
 
 	if( st_initialized && !st_finalized ){
 
+		g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
+
 		button = GTK_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "ActionIconBrowseButton" ));
 		gtk_widget_size_request( GTK_WIDGET( button ), &requisition );
 		g_debug( "%s: button requisition width=%d, height=%d", thisfn, requisition.width, requisition.height );
@@ -232,26 +219,20 @@ nact_iaction_tab_runtime_init_toplevel( NactIActionTab *instance )
 {
 	static const gchar *thisfn = "nact_iaction_tab_runtime_init_toplevel";
 	GtkWidget *label_widget, *tooltip_widget, *icon_widget;
-	GtkButton *enabled_button;
 	GtkWidget *button;
 
-	g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
 	g_return_if_fail( NACT_IS_IACTION_TAB( instance ));
 
 	if( st_initialized && !st_finalized ){
 
+		g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
+
 		base_window_signal_connect(
 				BASE_WINDOW( instance ),
 				G_OBJECT( instance ),
 				MAIN_WINDOW_SIGNAL_SELECTION_CHANGED,
 				G_CALLBACK( on_tab_updatable_selection_changed ));
 
-		base_window_signal_connect(
-				BASE_WINDOW( instance ),
-				G_OBJECT( instance ),
-				TAB_UPDATABLE_SIGNAL_PROVIDER_CHANGED,
-				G_CALLBACK( on_tab_updatable_provider_changed ));
-
 		base_window_signal_connect(
 				BASE_WINDOW( instance ),
 				G_OBJECT( instance ),
@@ -310,7 +291,7 @@ nact_iaction_tab_runtime_init_toplevel( NactIActionTab *instance )
 		icon_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionIconComboBoxEntry" );
 		base_window_signal_connect(
 				BASE_WINDOW( instance ),
-				G_OBJECT( GTK_BIN( icon_widget )->child ),
+				G_OBJECT( gtk_bin_get_child( GTK_BIN( icon_widget ))),
 				"changed",
 				G_CALLBACK( on_icon_changed ));
 
@@ -320,20 +301,6 @@ nact_iaction_tab_runtime_init_toplevel( NactIActionTab *instance )
 				G_OBJECT( button ),
 				"clicked",
 				G_CALLBACK( on_icon_browse ));
-
-		enabled_button = get_enabled_button( instance );
-		base_window_signal_connect(
-				BASE_WINDOW( instance ),
-				G_OBJECT( enabled_button ),
-				"toggled",
-				G_CALLBACK( on_enabled_toggled ));
-
-		button = base_window_get_widget( BASE_WINDOW( instance ), "ActionReadonlyButton" );
-		base_window_signal_connect(
-				BASE_WINDOW( instance ),
-				G_OBJECT( button ),
-				"toggled",
-				G_CALLBACK( on_readonly_toggled ));
 	}
 }
 
@@ -342,10 +309,11 @@ nact_iaction_tab_all_widgets_showed( NactIActionTab *instance )
 {
 	static const gchar *thisfn = "nact_iaction_tab_all_widgets_showed";
 
-	g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
 	g_return_if_fail( NACT_IS_IACTION_TAB( instance ));
 
 	if( st_initialized && !st_finalized ){
+
+		g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
 	}
 }
 
@@ -354,11 +322,12 @@ nact_iaction_tab_dispose( NactIActionTab *instance )
 {
 	static const gchar *thisfn = "nact_iaction_tab_dispose";
 
-	g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
 	g_return_if_fail( NACT_IS_IACTION_TAB( instance ));
 
 	if( st_initialized && !st_finalized ){
 
+		g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
+
 		release_icon_combobox( instance );
 	}
 }
@@ -399,7 +368,7 @@ on_iactions_list_column_edited( NactIActionTab *instance, NAObject *object, gcha
 
 	if( st_initialized && !st_finalized ){
 
-		if( NA_IS_OBJECT_ACTION( object )){
+		if( object && NA_IS_OBJECT_ITEM( object )){
 			label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionMenuLabelEntry" );
 			gtk_entry_set_text( GTK_ENTRY( label_widget ), text );
 		}
@@ -410,63 +379,64 @@ static void
 on_tab_updatable_selection_changed( NactIActionTab *instance, gint count_selected )
 {
 	static const gchar *thisfn = "nact_iaction_tab_on_tab_updatable_selection_changed";
-	NAObjectItem *item;
 	gboolean enable_tab;
+	NAObjectItem *item;
+	gboolean editable;
 	gboolean target_selection, target_location, target_toolbar;
 	gboolean enable_label;
 	gboolean same_label;
-	GtkWidget *label_widget, *tooltip_widget, *icon_widget, *title_widget;
+	GtkWidget *label_widget, *tooltip_widget, *icon_widget;
 	gchar *label, *tooltip, *icon;
 	GtkButton *icon_button;
-	GtkButton *enabled_button;
-	GtkToggleButton *readonly_button;
-	gboolean enabled_item;
 	GtkToggleButton *toggle;
-	gboolean editable;
-	GtkNotebook *notebook;
-	GtkWidget *page;
 
-	g_debug( "%s: instance=%p, count_selected=%d", thisfn, ( void * ) instance, count_selected );
 	g_return_if_fail( BASE_IS_WINDOW( instance ));
 	g_return_if_fail( NACT_IS_IACTION_TAB( instance ));
 
 	if( st_initialized && !st_finalized ){
 
-		st_on_selection_change = TRUE;
-
-		g_object_get(
-				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_EDITED_ACTION, &item,
-				TAB_UPDATABLE_PROP_EDITABLE, &editable,
-				NULL );
-
-		g_return_if_fail( !item || NA_IS_OBJECT_ITEM( item ));
+		g_debug( "%s: instance=%p, count_selected=%d", thisfn, ( void * ) instance, count_selected );
 
 		enable_tab = ( count_selected == 1 );
 		nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_ACTION, enable_tab );
 
-		target_selection = ( item && (
-				( NA_IS_OBJECT_ACTION( item ) && na_object_is_target_selection( item )) ||
-				( NA_IS_OBJECT_MENU( item ))));
+		st_on_selection_change = TRUE;
 
-		target_location = ( item && (
-				( NA_IS_OBJECT_ACTION( item ) && na_object_is_target_location( item )) ||
-				( NA_IS_OBJECT_MENU( item ))));
+		g_object_get(
+			G_OBJECT( instance ),
+			TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
+			TAB_UPDATABLE_PROP_EDITABLE, &editable,
+			NULL );
 
-		target_toolbar = ( item && (
-				( NA_IS_OBJECT_ACTION( item ) && na_object_is_target_toolbar( NA_OBJECT_ACTION( item )))));
+		target_selection =
+				enable_tab &&
+				item != NULL &&
+				NA_IS_OBJECT_ACTION( item ) &&
+				na_object_is_target_selection( item );
+
+		target_location =
+				enable_tab &&
+				item != NULL &&
+				NA_IS_OBJECT_ACTION( item ) &&
+				na_object_is_target_location( item );
+
+		target_toolbar =
+				enable_tab &&
+				item != NULL &&
+				NA_IS_OBJECT_ACTION( item ) &&
+				na_object_is_target_toolbar( item );
 
 		toggle = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "ActionTargetSelectionButton" ));
-		gtk_toggle_button_set_active( toggle, target_selection );
+		gtk_toggle_button_set_active( toggle, target_selection || ( item && NA_IS_OBJECT_MENU( item )));
 		gtk_widget_set_sensitive( GTK_WIDGET( toggle ), item && NA_IS_OBJECT_ACTION( item ));
 		nact_gtk_utils_set_editable( GTK_OBJECT( toggle ), editable );
 
 		toggle = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "ActionTargetLocationButton" ));
-		gtk_toggle_button_set_active( toggle, target_location );
+		gtk_toggle_button_set_active( toggle, target_location || ( item && NA_IS_OBJECT_MENU( item )));
 		gtk_widget_set_sensitive( GTK_WIDGET( toggle ), item && NA_IS_OBJECT_ACTION( item ));
 		nact_gtk_utils_set_editable( GTK_OBJECT( toggle ), editable );
 
-		enable_label = ( item && ( NA_IS_OBJECT_MENU( item ) || target_selection || target_location ));
+		enable_label = target_selection || target_location || ( item && NA_IS_OBJECT_MENU( item ));
 		label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionMenuLabelEntry" );
 		label = item ? na_object_get_label( item ) : g_strdup( "" );
 		label = label ? label : g_strdup( "" );
@@ -484,120 +454,70 @@ on_tab_updatable_selection_changed( NactIActionTab *instance, gint count_selecte
 		nact_gtk_utils_set_editable( GTK_OBJECT( toggle ), editable );
 
 		toggle = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "ToolbarSameLabelButton" ));
-		same_label = item && NA_IS_OBJECT_ACTION( item ) ? na_object_is_toolbar_same_label( NA_OBJECT_ACTION( item )) : FALSE;
+		same_label = item && NA_IS_OBJECT_ACTION( item ) ? na_object_is_toolbar_same_label( item ) : FALSE;
 		gtk_toggle_button_set_active( toggle, same_label );
-		toolbar_same_label_set_sensitive( instance, item );
+		gtk_widget_set_sensitive( GTK_WIDGET( toggle ), target_toolbar );
 		nact_gtk_utils_set_editable( GTK_OBJECT( toggle ), editable );
 
 		label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionToolbarLabelEntry" );
 		label = item && NA_IS_OBJECT_ACTION( item ) ? na_object_get_toolbar_label( item ) : g_strdup( "" );
-		label = label ? label : g_strdup( "" );
 		gtk_entry_set_text( GTK_ENTRY( label_widget ), label );
 		g_free( label );
-		toolbar_label_set_sensitive( instance, item );
+		gtk_widget_set_sensitive( label_widget, target_toolbar && !same_label );
 		nact_gtk_utils_set_editable( GTK_OBJECT( label_widget ), editable );
 
+		label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionToolbarLabelLabel" );
+		gtk_widget_set_sensitive( label_widget, target_toolbar && !same_label );
+
 		tooltip_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionTooltipEntry" );
 		tooltip = item ? na_object_get_tooltip( item ) : g_strdup( "" );
 		tooltip = tooltip ? tooltip : g_strdup( "" );
 		gtk_entry_set_text( GTK_ENTRY( tooltip_widget ), tooltip );
 		g_free( tooltip );
-		gtk_widget_set_sensitive( tooltip_widget, item != NULL );
 		nact_gtk_utils_set_editable( GTK_OBJECT( tooltip_widget ), editable );
 
 		icon_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionIconComboBoxEntry" );
 		icon = item ? na_object_get_icon( item ) : g_strdup( "" );
 		icon = icon ? icon : g_strdup( "" );
-		gtk_entry_set_text( GTK_ENTRY( GTK_BIN( icon_widget )->child ), icon );
+		gtk_entry_set_text( GTK_ENTRY( gtk_bin_get_child( GTK_BIN( icon_widget ))), icon );
 		g_free( icon );
-		gtk_widget_set_sensitive( icon_widget, item != NULL );
 		nact_gtk_utils_set_editable( GTK_OBJECT( icon_widget ), editable );
 
 		icon_button = GTK_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "ActionIconBrowseButton" ));
-		gtk_widget_set_sensitive( GTK_WIDGET( icon_button ), item != NULL );
 		nact_gtk_utils_set_editable( GTK_OBJECT( icon_button ), editable );
 
-		if( enable_tab ){
-			notebook = GTK_NOTEBOOK( base_window_get_widget( BASE_WINDOW( instance ), "MainNotebook" ));
-			page = gtk_notebook_get_nth_page( notebook, TAB_ACTION );
-			title_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionPropertiesTitle" );
-			if( item && NA_IS_OBJECT_MENU( item )){
-				gtk_notebook_set_tab_label_text( notebook, page, _( "Menu" ));
-				gtk_label_set_markup( GTK_LABEL( title_widget ), _( "<b>Menu properties</b>" ));
-			} else {
-				gtk_notebook_set_tab_label_text( notebook, page, _( "Action" ));
-				gtk_label_set_markup( GTK_LABEL( title_widget ), _( "<b>Action properties</b>" ));
-			}
-		}
-
-		enabled_button = get_enabled_button( instance );
-		enabled_item = item ? na_object_is_enabled( NA_OBJECT_ITEM( item )) : FALSE;
-		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( enabled_button ), enabled_item );
-		gtk_widget_set_sensitive( GTK_WIDGET( enabled_button ), item != NULL );
-		nact_gtk_utils_set_editable( GTK_OBJECT( enabled_button ), editable );
-
-		/* read-only toggle only indicates the intrinsic writability status of this item
-		 * _not_ the writability status of the provider
-		 */
-		readonly_button = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "ActionReadonlyButton" ));
-		gtk_toggle_button_set_active( readonly_button, item ? na_object_is_readonly( item ) : FALSE );
-		gtk_widget_set_sensitive( GTK_WIDGET( readonly_button ), item != NULL );
-		nact_gtk_utils_set_editable( GTK_OBJECT( readonly_button ), FALSE );
-
-		label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionItemID" );
-		label = item ? na_object_get_id( item ) : g_strdup( "" );
-		gtk_label_set_text( GTK_LABEL( label_widget ), label );
-		g_free( label );
-		gtk_widget_set_sensitive( label_widget, item != NULL );
-
-		display_provider_name( instance, item );
-
 		st_on_selection_change = FALSE;
 	}
 }
 
-static void
-on_tab_updatable_provider_changed( NactIActionTab *instance, NAObjectItem *item )
-{
-	static const gchar *thisfn = "nact_iaction_tab_on_tab_updatable_provider_changed";
-
-	g_debug( "%s: instance=%p, item=%p", thisfn, ( void * ) instance, ( void * ) item );
-
-	if( st_initialized && !st_finalized ){
-
-		display_provider_name( instance, item );
-	}
-}
-
 static void
 on_target_selection_toggled( GtkToggleButton *button, NactIActionTab *instance )
 {
 	static const gchar *thisfn = "nact_iaction_tab_on_target_selection_toggled";
-	NAObjectAction *action;
+	NAObjectItem *item;
 	gboolean is_target;
 	gboolean editable;
 
 	if( !st_on_selection_change ){
+
 		g_debug( "%s: button=%p, instance=%p", thisfn, ( void * ) button, ( void * ) instance );
 
 		g_object_get(
-				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_EDITED_ACTION, &action,
-				TAB_UPDATABLE_PROP_EDITABLE, &editable,
-				NULL );
+			G_OBJECT( instance ),
+			TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
+			TAB_UPDATABLE_PROP_EDITABLE, &editable,
+			NULL );
 
 		g_debug( "%s: item=%p (%s), editable=%s",
-				thisfn, ( void * ) action, action ? G_OBJECT_TYPE_NAME( action ) : "(null)",
+				thisfn, ( void * ) item, item ? G_OBJECT_TYPE_NAME( item ) : "null",
 				editable ? "True":"False" );
 
-		if( action && NA_IS_OBJECT_ACTION( action )){
-
+		if( item && NA_IS_OBJECT_ACTION( item )){
 			is_target = gtk_toggle_button_get_active( button );
 
 			if( editable ){
-				na_object_set_target_selection( action, is_target );
-				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ENABLE_TAB, action );
-				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, action, FALSE );
+				na_object_set_target_selection( item, is_target );
+				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, FALSE );
 
 			} else {
 				g_signal_handlers_block_by_func(( gpointer ) button, on_target_selection_toggled, instance );
@@ -612,31 +532,30 @@ static void
 on_target_location_toggled( GtkToggleButton *button, NactIActionTab *instance )
 {
 	static const gchar *thisfn = "nact_iaction_tab_on_target_location_toggled";
-	NAObjectAction *action;
+	NAObjectItem *item;
 	gboolean is_target;
 	gboolean editable;
 
 	if( !st_on_selection_change ){
+
 		g_debug( "%s: button=%p, instance=%p", thisfn, ( void * ) button, ( void * ) instance );
 
 		g_object_get(
-				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_EDITED_ACTION, &action,
-				TAB_UPDATABLE_PROP_EDITABLE, &editable,
-				NULL );
+			G_OBJECT( instance ),
+			TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
+			TAB_UPDATABLE_PROP_EDITABLE, &editable,
+			NULL );
 
 		g_debug( "%s: item=%p (%s), editable=%s",
-				thisfn, ( void * ) action, action ? G_OBJECT_TYPE_NAME( action ) : "(null)",
+				thisfn, ( void * ) item, item ? G_OBJECT_TYPE_NAME( item ) : "null",
 				editable ? "True":"False" );
 
-		if( action && NA_IS_OBJECT_ACTION( action )){
-
+		if( item && NA_IS_OBJECT_ACTION( item )){
 			is_target = gtk_toggle_button_get_active( button );
 
 			if( editable ){
-				na_object_set_target_location( action, is_target );
-				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ENABLE_TAB, action );
-				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, action, FALSE );
+				na_object_set_target_location( item, is_target );
+				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, FALSE );
 
 			} else {
 				g_signal_handlers_block_by_func(( gpointer ) button, on_target_location_toggled, instance );
@@ -650,7 +569,7 @@ on_target_location_toggled( GtkToggleButton *button, NactIActionTab *instance )
 static void
 check_for_label( NactIActionTab *instance, GtkEntry *entry, const gchar *label )
 {
-	NAObjectItem *edited;
+	NAObjectItem *item;
 
 	g_return_if_fail( NACT_IS_IACTION_TAB( instance ));
 	g_return_if_fail( GTK_IS_ENTRY( entry ));
@@ -665,10 +584,10 @@ check_for_label( NactIActionTab *instance, GtkEntry *entry, const gchar *label )
 
 		g_object_get(
 				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_EDITED_ACTION, &edited,
+				TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
 				NULL );
 
-		if( edited && g_utf8_strlen( label, -1 ) == 0 ){
+		if( item && g_utf8_strlen( label, -1 ) == 0 ){
 
 			/* i18n: status bar message when the action label is empty */
 			nact_main_statusbar_display_status(
@@ -684,24 +603,24 @@ check_for_label( NactIActionTab *instance, GtkEntry *entry, const gchar *label )
 static void
 on_label_changed( GtkEntry *entry, NactIActionTab *instance )
 {
-	NAObjectItem *edited;
+	NAObjectItem *item;
 	const gchar *label;
 
 	g_object_get(
 			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_EDITED_ACTION, &edited,
+			TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
 			NULL );
 
-	if( edited ){
+	if( item ){
 		label = gtk_entry_get_text( entry );
-		na_object_set_label( edited, label );
+		na_object_set_label( item, label );
 		check_for_label( instance, entry, label );
 
-		if( NA_IS_OBJECT_ACTION( edited )){
-			setup_toolbar_label( instance, edited, label );
+		if( NA_IS_OBJECT_ACTION( item )){
+			setup_toolbar_label( instance, item, label );
 		}
 
-		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, edited, TRUE );
+		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, TRUE );
 	}
 }
 
@@ -720,29 +639,32 @@ static void
 on_target_toolbar_toggled( GtkToggleButton *button, NactIActionTab *instance )
 {
 	static const gchar *thisfn = "nact_iaction_tab_on_target_toolbar_toggled";
-	NAObjectAction *action;
+	NAObjectAction *item;
 	gboolean is_target;
 	gboolean editable;
 
 	if( !st_on_selection_change ){
+
 		g_debug( "%s: button=%p, instance=%p", thisfn, ( void * ) button, ( void * ) instance );
 
 		g_object_get(
 				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_EDITED_ACTION, &action,
+				TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
 				TAB_UPDATABLE_PROP_EDITABLE, &editable,
 				NULL );
 
-		if( action && NA_IS_OBJECT_ACTION( action )){
+		g_debug( "%s: item=%p (%s), editable=%s",
+				thisfn, ( void * ) item, item ? G_OBJECT_TYPE_NAME( item ) : "null",
+				editable ? "True":"False" );
 
+		if( item && NA_IS_OBJECT_ACTION( item )){
 			is_target = gtk_toggle_button_get_active( button );
 
 			if( editable ){
-				na_object_set_target_toolbar( action, is_target );
-				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ENABLE_TAB, action );
-				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, action, FALSE );
-				toolbar_same_label_set_sensitive( instance, NA_OBJECT_ITEM( action ));
-				toolbar_label_set_sensitive( instance, NA_OBJECT_ITEM( action ));
+				na_object_set_target_toolbar( item, is_target );
+				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, FALSE );
+				toolbar_same_label_set_sensitive( instance, NA_OBJECT_ITEM( item ));
+				toolbar_label_set_sensitive( instance, NA_OBJECT_ITEM( item ));
 
 			} else {
 				g_signal_handlers_block_by_func(( gpointer ) button, on_target_toolbar_toggled, instance );
@@ -757,7 +679,7 @@ static void
 on_toolbar_same_label_toggled( GtkToggleButton *button, NactIActionTab *instance )
 {
 	static const gchar *thisfn = "nact_iaction_tab_on_toolbar_same_label_toggled";
-	NAObjectItem *edited;
+	NAObjectItem *item;
 	gboolean same_label;
 	gboolean editable;
 	gchar *label;
@@ -768,25 +690,30 @@ on_toolbar_same_label_toggled( GtkToggleButton *button, NactIActionTab *instance
 
 		g_object_get(
 				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_EDITED_ACTION, &edited,
+				TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
 				TAB_UPDATABLE_PROP_EDITABLE, &editable,
 				NULL );
 
-		if( edited && NA_IS_OBJECT_ACTION( edited )){
+		g_debug( "%s: item=%p (%s), editable=%s",
+				thisfn, ( void * ) item, item ? G_OBJECT_TYPE_NAME( item ) : "null",
+				editable ? "True":"False" );
 
+		if( item && NA_IS_OBJECT_ACTION( item )){
 			same_label = gtk_toggle_button_get_active( button );
 
 			if( editable ){
-				na_object_set_toolbar_same_label( NA_OBJECT_ACTION( edited ), same_label );
+				na_object_set_toolbar_same_label( NA_OBJECT_ACTION( item ), same_label );
+
 				if( same_label ){
-					label = na_object_get_label( edited );
+					label = na_object_get_label( item );
 					label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionToolbarLabelEntry" );
 					gtk_entry_set_text( GTK_ENTRY( label_widget ), label );
 					g_free( label );
 				}
-				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, edited, FALSE );
-				toolbar_same_label_set_sensitive( instance, NA_OBJECT_ITEM( edited ));
-				toolbar_label_set_sensitive( instance, NA_OBJECT_ITEM( edited ));
+
+				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, FALSE );
+				toolbar_same_label_set_sensitive( instance, NA_OBJECT_ITEM( item ));
+				toolbar_label_set_sensitive( instance, NA_OBJECT_ITEM( item ));
 
 			} else {
 				g_signal_handlers_block_by_func(( gpointer ) button, on_toolbar_same_label_toggled, instance );
@@ -829,20 +756,19 @@ setup_toolbar_label( NactIActionTab *instance, NAObjectItem *item, const gchar *
 static void
 on_toolbar_label_changed( GtkEntry *entry, NactIActionTab *instance )
 {
-	NAObjectItem *edited;
+	NAObjectItem *item;
 	const gchar *label;
 
 	g_object_get(
 			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_EDITED_ACTION, &edited,
+			TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
 			NULL );
 
-	if( edited && NA_IS_OBJECT_ACTION( edited )){
-
+	if( item && NA_IS_OBJECT_ACTION( item )){
 		label = gtk_entry_get_text( entry );
-		na_object_set_toolbar_label( NA_OBJECT_ACTION( edited ), label );
+		na_object_set_toolbar_label( NA_OBJECT_ACTION( item ), label );
 
-		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, edited, FALSE );
+		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, FALSE );
 	}
 }
 
@@ -862,16 +788,16 @@ toolbar_label_set_sensitive( NactIActionTab *instance, NAObjectItem *item )
 static void
 on_tooltip_changed( GtkEntry *entry, NactIActionTab *instance )
 {
-	NAObjectItem *edited;
+	NAObjectItem *item;
 
 	g_object_get(
 			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_EDITED_ACTION, &edited,
+			TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
 			NULL );
 
-	if( edited ){
-		na_object_set_tooltip( edited, gtk_entry_get_text( entry ));
-		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, edited, FALSE );
+	if( item ){
+		na_object_set_tooltip( item, gtk_entry_get_text( entry ));
+		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, FALSE );
 	}
 }
 
@@ -924,6 +850,7 @@ icon_combo_list_fill( GtkComboBoxEntry* combo )
 	if( gtk_combo_box_entry_get_text_column( combo ) == -1 ){
 		gtk_combo_box_entry_set_text_column( combo, ICON_STOCK_COLUMN );
 	}
+
 	gtk_cell_layout_clear( GTK_CELL_LAYOUT( combo ));
 
 	cell_renderer_pix = gtk_cell_renderer_pixbuf_new();
@@ -940,50 +867,14 @@ icon_combo_list_fill( GtkComboBoxEntry* combo )
 static void
 on_icon_browse( GtkButton *button, NactIActionTab *instance )
 {
-	GtkWidget *dialog;
-	GtkWindow *toplevel;
-	gchar *filename;
 	GtkWidget *icon_widget;
-	NactApplication *application;
-	NAUpdater *updater;
-	gchar *path;
 
-	toplevel = base_window_get_toplevel( BASE_WINDOW( instance ));
+	icon_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionIconComboBoxEntry" );
 
-	dialog = gtk_file_chooser_dialog_new(
-			_( "Choosing an icon" ),
-			toplevel,
-			GTK_FILE_CHOOSER_ACTION_OPEN,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-			GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-			NULL
-			);
-
-	base_iprefs_position_named_window( BASE_WINDOW( instance ), GTK_WINDOW( dialog ), IPREFS_ICONS_DIALOG );
-
-	application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( instance )));
-	updater = nact_application_get_updater( application );
-
-	path = na_iprefs_read_string( NA_IPREFS( updater ), IPREFS_ICONS_PATH, "" );
-	if( path && g_utf8_strlen( path, -1 )){
-		gtk_file_chooser_set_current_folder( GTK_FILE_CHOOSER( dialog ), path );
-	}
-	g_free( path );
-
-	if( gtk_dialog_run( GTK_DIALOG( dialog )) == GTK_RESPONSE_ACCEPT ){
-		filename = gtk_file_chooser_get_filename( GTK_FILE_CHOOSER( dialog ));
-		icon_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionIconComboBoxEntry" );
-		gtk_entry_set_text( GTK_ENTRY( GTK_BIN( icon_widget )->child ), filename );
-	    g_free (filename);
-
-		path = gtk_file_chooser_get_current_folder( GTK_FILE_CHOOSER( dialog ));
-	    nact_iprefs_write_string( BASE_WINDOW( instance ), IPREFS_ICONS_PATH, path );
-		g_free( path );
-	  }
-
-	base_iprefs_save_named_window_position( BASE_WINDOW( instance ), GTK_WINDOW( dialog ), IPREFS_ICONS_DIALOG );
-
-	gtk_widget_destroy( dialog );
+	nact_gtk_utils_select_file(
+			BASE_WINDOW( instance ),
+			_( "Choosing an icon" ), IPREFS_ICONS_DIALOG,
+			gtk_bin_get_child( GTK_BIN( icon_widget )), IPREFS_ICONS_DIALOG, "" );
 }
 
 static void
@@ -991,7 +882,7 @@ on_icon_changed( GtkEntry *icon_entry, NactIActionTab *instance )
 {
 	static const gchar *thisfn = "nact_iaction_tab_on_icon_changed";
 	GtkImage *image;
-	NAObjectItem *edited;
+	NAObjectItem *item;
 	const gchar *icon_name;
 
 	g_debug( "%s: entry=%p, instance=%p", thisfn, ( void * ) icon_entry, ( void * ) instance );
@@ -1000,15 +891,18 @@ on_icon_changed( GtkEntry *icon_entry, NactIActionTab *instance )
 
 	g_object_get(
 			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_EDITED_ACTION, &edited,
+			TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
 			NULL );
 
-	if( edited ){
+	if( item ){
 		icon_name = gtk_entry_get_text( icon_entry );
-		na_object_set_icon( edited, icon_name );
-		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, edited, TRUE );
+		na_object_set_icon( item, icon_name );
+		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, TRUE );
 	}
 
+	/* icon_name may be null if there is no current item
+	 * in such a case, we blank the image
+	 */
 	image = GTK_IMAGE( base_window_get_widget( BASE_WINDOW( instance ), "ActionIconImage" ));
 	nact_gtk_utils_render( icon_name, image, GTK_ICON_SIZE_MENU );
 }
@@ -1075,83 +969,3 @@ release_icon_combobox( NactIActionTab *instance )
 	model = gtk_combo_box_get_model( GTK_COMBO_BOX( combo ));
 	gtk_list_store_clear( GTK_LIST_STORE( model ));
 }
-
-static GtkButton *
-get_enabled_button( NactIActionTab *instance )
-{
-	return( GTK_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "ActionEnabledButton" )));
-}
-
-static void
-on_enabled_toggled( GtkToggleButton *button, NactIActionTab *instance )
-{
-	static const gchar *thisfn = "nact_iaction_tab_on_enabled_toggled";
-	NAObjectItem *edited;
-	gboolean enabled;
-	gboolean editable;
-
-	if( !st_on_selection_change ){
-		g_debug( "%s: button=%p, instance=%p", thisfn, ( void * ) button, ( void * ) instance );
-
-		g_object_get(
-				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_EDITED_ACTION, &edited,
-				TAB_UPDATABLE_PROP_EDITABLE, &editable,
-				NULL );
-
-		if( edited && NA_IS_OBJECT_ITEM( edited )){
-
-			enabled = gtk_toggle_button_get_active( button );
-
-			if( editable ){
-				na_object_set_enabled( edited, enabled );
-				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, edited, FALSE );
-
-			} else {
-				g_signal_handlers_block_by_func(( gpointer ) button, on_enabled_toggled, instance );
-				gtk_toggle_button_set_active( button, !enabled );
-				g_signal_handlers_unblock_by_func(( gpointer ) button, on_enabled_toggled, instance );
-			}
-		}
-	}
-}
-
-static void
-on_readonly_toggled( GtkToggleButton *button, NactIActionTab *instance )
-{
-	static const gchar *thisfn = "nact_iaction_tab_on_readonly_toggled";
-	gboolean active;
-
-	if( !st_on_selection_change ){
-		g_debug( "%s: button=%p, instance=%p", thisfn, ( void * ) button, ( void * ) instance );
-
-		active = gtk_toggle_button_get_active( button );
-
-		g_signal_handlers_block_by_func(( gpointer ) button, on_readonly_toggled, instance );
-		gtk_toggle_button_set_active( button, !active );
-		g_signal_handlers_unblock_by_func(( gpointer ) button, on_readonly_toggled, instance );
-	}
-}
-
-static void
-display_provider_name( NactIActionTab *instance, NAObjectItem *item )
-{
-	GtkWidget *label_widget;
-	gchar *label;
-	NAIOProvider *provider;
-
-	label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionItemProvider" );
-	label = NULL;
-	if( item ){
-		provider = na_object_get_provider( item );
-		if( provider ){
-			label = na_io_provider_get_name( provider );
-		}
-	}
-	if( !label ){
-		label = g_strdup( "" );
-	}
-	gtk_label_set_text( GTK_LABEL( label_widget ), label );
-	g_free( label );
-	gtk_widget_set_sensitive( label_widget, item != NULL );
-}
